<template>
    <div class="system-add-menu-container">
        <el-dialog :title="title" :visible.sync="isShowApproveBasicDialog" width="600px" :close-on-click-modal="false">
            <el-form :model="approveBasicForm" :rules="approveBasicFormRules" ref="approveBasicFormRef" size="default" label-width="120px">
                <el-row :gutter="35">
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="标题" prop="title">
                            <el-input class="input-add" :disabled="!disabled" v-model.trim="approveBasicForm.title" placeholder="请输入标题名称" clearable></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="标准类型" prop="ruleStandType">
                            <el-select class="input-add" :disabled="!disabled" v-model="approveBasicForm.ruleStandType" placeholder="请选择标准类型" clearable filterable>
                                <el-option v-for="item in ruleStandTypeList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                            </el-select>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="最大值" prop="maxVal">
                            <el-input :disabled="!disabled" v-model="approveBasicForm.maxVal" type="number" class="input-add" placeholder="请根据需求选择">
                                <template slot="prepend">
                                    <el-select :disabled="!disabled" v-model="approveBasicForm.maxValMatchPattern" placeholder="请根据需求选择" style="width: 115px">
                                        <el-option v-for="item in typeTwoList" :key="item.id" :value="item.id" :label="item.name"> </el-option>
                                    </el-select>
                                </template>
                            </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="最小值" prop="minVal">
                            <el-input :disabled="!disabled" v-model="approveBasicForm.minVal" type="number" class="input-add" placeholder="请根据需求选择">
                                <template slot="prepend">
                                    <el-select :disabled="!disabled" v-model="approveBasicForm.minValMatchPattern" placeholder="请根据需求选择" style="width: 115px">
                                        <el-option v-for="item in typeList" :key="item.id" :value="item.id" :label="item.name"> </el-option>
                                    </el-select>
                                </template>
                            </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
                        <el-form-item label="描述" prop="info">
                            <el-input class="input-add" :rows="3" :disabled="!disabled" v-model.trim="approveBasicForm.info" type="textarea" placeholder="请输入描述"></el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <template #footer>
                <div class="dialog-footer" v-show="disabled" align="right">
                    <el-button @click="isShowApproveBasicDialog = !isShowApproveBasicDialog" size="default">取 消</el-button>
                    <el-button type="primary" @click="submitApproveBasic" size="default">确 定</el-button>
                </div>
            </template>
        </el-dialog>
    </div>
</template>

<script>
import {approveBasicApi} from "../../../../../api/approveBasic";
export default {
    name: 'approveBasicDialog',
    data(){
        return{
            title: '',
            disabled: false,
            personTime: false,
            departmentList: [],
            isShowApproveBasicDialog: false,
            ruleStandTypeList: [
                { id: 1, name: '可燃气浓度' },
                { id: 2, name: '氧气浓度' },
                { id: 3, name: '一氧化碳浓度' },
                { id: 4, name: '硫化氢浓度' },
                { id: 5, name: '温度' },
                { id: 6, name: '压力' },
                { id: 7, name: '震动' }
            ],
            typeList: [
                { id: 1, name: '大于' },
                { id: 2, name: '等于' },
                { id: 4, name: '大于等于' }
            ],
            typeTwoList: [
                { id: 3, name: '小于' },
                { id: 2, name: '等于' },
                { id: 5, name: '小于等于' }
            ],
            approveBasicForm: {
                ruleStandType: null,
                minVal: null,
                minValMatchPattern: null,
                maxVal: null,
                maxValMatchPattern: null,
                title: null,
                info: null
            },
            approveBasicFormRules: {
                ruleStandType: [{ required: true, message: '请选择标准类型', trigger: 'change' }],
                minVal: [{ required: true, message: '请填写标最低值', trigger: 'blur' }],
                maxVal: [{ required: true, message: '请填写标最高值', trigger: 'blur' }],
                title: [{ required: true, message: '请选择风险等级', trigger: 'blur' }],
                info: [{ required: true, message: '请填写描述信息', trigger: 'blur' }]
            }
        }
    },
    methods:{
        showApproveBasicDialog(type, value) {
            this.isShowApproveBasicDialog = true;
            this.$nextTick(() =>{
                this.$refs["approveBasicFormRef"].clearValidate()
            })
            if (type === '新增') {
                this.disabled = true;
                this.personTime = false;
                this.title = '新增审批标准';
                this.approveBasicForm = {
                    ruleStandType: null,
                    minVal: null,
                    minValMatchPattern: null,
                    maxVal: null,
                    maxValMatchPattern: null,
                    title: null,
                    info: null
                };
            } else if (type === '查看') {
                this.disabled = false;
                this.personTime = true;
                this.title = '查看审批标准';
                this.approveBasicForm = JSON.parse(JSON.stringify(value));
            } else {
                this.disabled = true;
                this.personTime = false;
                this.title = '修改审批标准';
                this.approveBasicForm = JSON.parse(JSON.stringify(value));
            }
        },

        submitApproveBasic() {
            this.$refs["approveBasicFormRef"].validate(async (valid) => {
                if (valid) {
                    if (this.title === '新增审批标准') {
                        let res = await approveBasicApi().addApproveBasic(this.approveBasicForm);
                        if (res.data.code === '200') {
                            this.$message({
                                type: 'success',
                                message: '审批标准新增成功',
                                duration: 2000
                            });
                            this.isShowApproveBasicDialog = false;
                            this.$emit('refreshApproveBasic');
                        } else {
                            this.$message({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    } else {
                        let res = await approveBasicApi().modApproveBasic(this.approveBasicForm);
                        if (res.data.code === '200') {
                            this.$message({
                                type: 'success',
                                message: '审批标准修改成功',
                                duration: 2000
                            });
                            this.isShowApproveBasicDialog = false;
                            this.$emit('refreshApproveBasic');
                        } else {
                            this.$message({
                                type: 'warning',
                                message: res.data.msg
                            });
                        }
                    }
                } else {
                    this.$message({
                        type: 'warning',
                        message: '请完善基本信息'
                    });
                }
            });
        },
    },

};
</script>

<style scoped>
</style>
